@@ -298,10 +298,7 @@ void KConfigIniBackend::writeEntries(const QByteArray &locale, QIODevice &file,
 {
     QString currentGroup;
     bool groupIsImmutable = false;
-    const auto end = map.cend();
-    for (auto it = map.cbegin(); it != end; ++it) {
-        const KEntryKey &key = it.key();
-
+    for (const auto &[key, entry] : map) {
         // Either process the default group or all others
         if ((key.mGroup != QStringLiteral("<default>")) == defaultGroup) {
             continue; // skip
@@ -309,11 +306,11 @@ void KConfigIniBackend::writeEntries(const QByteArray &locale, QIODevice &file,
 
         // the only thing we care about groups is, is it immutable?
         if (key.mKey.isNull()) {
-            groupIsImmutable = it->bImmutable;
+            groupIsImmutable = entry.bImmutable;
             continue; // skip
         }
 
-        const KEntry &currentEntry = *it;
+        const KEntry &currentEntry = entry;
         if (!defaultGroup && currentGroup != key.mGroup) {
             if (!firstEntry) {
                 file.putChar('\n');
@@ -418,35 +415,32 @@ bool KConfigIniBackend::writeConfig(const QByteArray &locale, KEntryMap &entryMa
         }
     }
 
-    const KEntryMapIterator end = entryMap.end();
-    for (KEntryMapIterator it = entryMap.begin(); it != end; ++it) {
-        if (!it.key().mKey.isEmpty() && !it->bDirty) { // not dirty, doesn't overwrite entry in writeMap. skips default entries, too.
+    for (auto &[key, entry] : entryMap) {
+        if (!key.mKey.isEmpty() && !entry.bDirty) { // not dirty, doesn't overwrite entry in writeMap. skips default entries, too.
             continue;
         }
 
-        const KEntryKey &key = it.key();
-
         // only write entries that have the same "globality" as the file
-        if (it->bGlobal == bGlobal) {
-            if (it->bReverted && it->bOverridesGlobal) {
-                it->bDeleted = true;
-                writeMap[key] = *it;
-            } else if (it->bReverted) {
-                writeMap.remove(key);
-            } else if (!it->bDeleted) {
-                writeMap[key] = *it;
+        if (entry.bGlobal == bGlobal) {
+            if (entry.bReverted && entry.bOverridesGlobal) {
+                entry.bDeleted = true;
+                writeMap[key] = entry;
+            } else if (entry.bReverted) {
+                writeMap.erase(key);
+            } else if (!entry.bDeleted) {
+                writeMap[key] = entry;
             } else {
                 KEntryKey defaultKey = key;
                 defaultKey.bDefault = true;
-                if (!entryMap.contains(defaultKey) && !it->bOverridesGlobal) {
-                    writeMap.remove(key); // remove the deleted entry if there is no default
+                if (entryMap.find(defaultKey) == entryMap.end() && !entry.bOverridesGlobal) {
+                    writeMap.erase(key); // remove the deleted entry if there is no default
                     // qDebug() << "Detected as deleted=>removed:" << key.mGroup << key.mKey << "global=" << bGlobal;
                 } else {
-                    writeMap[key] = *it; // otherwise write an explicitly deleted entry
+                    writeMap[key] = entry; // otherwise write an explicitly deleted entry
                     // qDebug() << "Detected as deleted=>[$d]:" << key.mGroup << key.mKey << "global=" << bGlobal;
                 }
             }
-            it->bDirty = false;
+            entry.bDirty = false;
         }
     }
 
@@ -732,7 +726,7 @@ public:
         return true;
     }
     // Return true if Utf8Char contains one valid character.
-    bool isComplete()
+    bool isComplete() const
     {
         return count > 0 && count == charLength;
     }
